#
# spec file for package npth
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2025 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname	libnpth0
Name:           npth
Version:        1.8
Release:        2.1
Summary:        GNU Portable Threads library
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://gnupg.org/software/npth/
#Git-Clone:	git://git.gnupg.org/npth
#DL-URL:        https://gnupg.org/download/index.html#npth
Source:         https://gnupg.org/ftp/gcrypt/%name/%name-%version.tar.bz2
Source2:        https://gnupg.org/ftp/gcrypt/%name/%name-%version.tar.bz2.sig
# https://www.gnupg.org/signature_key.html
Source4:        https://gnupg.org/signature_key.asc#/%name.keyring
Source99:       %name.changes

%description
nPth is a non-preemptive threads implementation using an API
similar to the one in GNU Pth. In contrast to Pth, nPth is
based on the system's standard threads implementation. Thus, nPth
allows the use of libraries which are not compatible to GNU Pth.

%package -n %lname
Summary:        GNU Portable Threads library
Group:          System/Libraries

%description -n %lname
nPth is a non-preemptive threads implementation using an API
similar to the one in GNU Pth. In contrast to Pth, nPth is
based on the system's standard threads implementation. Thus, nPth
allows the use of libraries which are not compatible to GNU Pth.

%package devel
Summary:        Development files for the GNU New Portable Threads library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
nPth is a non-preemptive threads implementation using an API
similar to the one in GNU Pth.

This subpackage contains the headers for npth.

%prep
%autosetup -p1

%build
date=$(date -u "+%%Y-%%m-%%dT%%H:%%M+0000" -r %SOURCE99)
%configure \
	--enable-build-timestamp="$date"
%make_build

%install
%make_install
find "%buildroot" -type f -name "*.la" -delete -print

%check
%make_build check

%ldconfig_scriptlets -n %lname

%files -n %lname
%license COPYING.LIB
%_libdir/libnpth.so.*

%files devel
%license COPYING.LIB
%doc AUTHORS ChangeLog NEWS README
%_libdir/libnpth.so
%_libdir/pkgconfig/*
%_includedir/*
%_datadir/aclocal/*

%changelog
* Tue Mar  4 2025 Valentin Lefebvre <valentin.lefebvre@suse.com>
- specfile: update license to LGPL-2.1-or-later
* Fri Jan 31 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to 1.8:
  * New function npth_get_version
  * New macros NPTH_VERSION and NPTH_VERSION_NUMBER
  * Fix INSERT_EXPOSE_RWLOCK_API for musl C library
  * Return a run-time error if npth_rwlock_timedrdlock is not
    supported
* Mon Feb 26 2024 Pedro Monreal <pmonreal@suse.com>
- Update to 1.7:
  * The npth-config command is not installed by default, because it is
    now replaced by use of pkg-config/gpgrt-config with npth.pc.
    Supply --enable-install-npth-config configure option, if needed.
  * Support for legacy systems w/o pthread_rwlock_t support.  [T4306]
  * New functions npth_poll and npth_ppoll for Unix.  [T5748]
  * Fixes to improve support for 64 bit Windows.
  * Fix declaration conflict using newer mingw versions.  [T5889]
  * Fix build problems on Solaris 11.  [T4491]
  * Fix detecting of the pthread library.  [rPTH6629a4b801]
  * Clean up handling of unsafe semaphores on AIX.  [T6947]
  * Link without -flat_namespace to support macOS 11.  [T5610]
  * Release-info: https://dev.gnupg.org/T7010
  * Update spec file
  * Update upstream npth.keyring
* Fri Sep  4 2020 Jan Engelhardt <jengelh@inai.de>
- Remove old specfile constructs and doubleshipping of docs.
* Mon Jul 16 2018 kbabioch@suse.com
- Update to 1.6:
  * Fix library requirements for HPUX.
* Thu Feb 22 2018 fvogt@suse.com
- Use %%license (boo#1082318)
* Sun Jun  4 2017 astieger@suse.com
- update to 1.5:
  * Fix the busy waiting emulation of pthread_mutex_timedlock for
    Unices lacking that function
* Tue May 16 2017 astieger@suse.com
- update to 1.4:
  * fixes for platforms other than GNU/Linux
  * New function npth_is_protected to help debugging.
  * Change license from LGPLv3+/GPLv2+ to LGPLv2+.
- run tests
- update signing keyring
- package license text and other information
* Thu Dec  1 2016 astieger@suse.com
- update to 1.3:
  * Bypass npth_protect/npth_unprotect iff the library has not yet
    been initialized.
  * Improve detection of clock_gettime
- use reproducible build timestamp
* Sat Apr 11 2015 astieger@suse.com
- npth 1.2:
  * Fix possible clobbering of ERRNO.
* Sun Nov  2 2014 andreas.stieger@gmx.de
- npth 1.1:
  * fixes for platforms other than GNU/Linux
* Sun Sep 21 2014 andreas.stieger@gmx.de
- npth 1.0:
  * improvements to the build system
  * restore sigmask at fork
- spec file cleanup:
  * gpg-offline covered by source_validator
  * use source URLs
* Wed Nov 28 2012 sbrabec@suse.cz
- Verify GPG signature.
* Tue Sep  4 2012 jengelh@inai.de
- Update to new upstream release 0.91
  * npth_init does now return an error on failure.
  * Provide a pselect emulation for OpenBSD et al.
* Tue May 29 2012 jengelh@inai.de
- Initial package for build.opensuse.org
